﻿using Infragistics.Win.DataVisualization;
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;

namespace WDC_HighlightMarkers
{
    public partial class Form1 : Form
    {
        private const int HIGHLIGHT_VALUE = 1;
        private const int NORMAL_VALUE = 0;

        private const int MARKER_SIZE = 40;

        private readonly Color normalMarkerColor = Color.Blue;
        private readonly Color highlightedMarkerColor = Color.Red;

        public Form1()
        {
            InitializeComponent();
        }

        private void Form1_Load(object sender, EventArgs e)
        {
            ScatterLineSeries series = new ScatterLineSeries();
            BubbleSeries markers = new BubbleSeries();
            DataTable scatterTable = CreateScatterTable();

            NumericXAxis xAxis = new NumericXAxis();
            NumericYAxis yAxis = new NumericYAxis();

            series.DataSource = scatterTable;
            series.XAxis = xAxis;
            series.YAxis = yAxis;
            series.XMemberPath = "ValuesX";
            series.YMemberPath = "ValuesY";

            markers.DataSource = scatterTable;
            markers.XAxis = xAxis;
            markers.YAxis = yAxis;
            markers.XMemberPath = "ValuesX";
            markers.YMemberPath = "ValuesY";
            markers.RadiusMemberPath = "Radius";
            markers.FillMemberPath = "Fill";
            markers.MarkerType = MarkerType.Circle;
            markers.Name = "Markers";          

            var scale = new ValueBrushScale();
            scale.Brushes.Add(new SolidBrush(normalMarkerColor));
            scale.Brushes.Add(new SolidBrush(highlightedMarkerColor));
            scale.MinimumValue = 0;
            scale.MaximumValue = 1;
            markers.FillScale = scale;

            ultraDataChart1.Axes.Add(xAxis);
            ultraDataChart1.Axes.Add(yAxis);

            ultraDataChart1.Series.Add(series);
            ultraDataChart1.Series.Add(markers);
        }

        private DataTable CreateScatterTable()
        {
            DataTable dt = new DataTable();

            dt.Columns.Add("Labels", typeof(string));
            dt.Columns.Add("ValuesX", typeof(int));
            dt.Columns.Add("ValuesY", typeof(int));
            dt.Columns.Add("Radius", typeof(int));
            dt.Columns.Add("Fill", typeof(int));

            dt.Rows.Add(new object[] { "January", 200, 150, MARKER_SIZE, NORMAL_VALUE });
            dt.Rows.Add(new object[] { "February", 280, 180, MARKER_SIZE, NORMAL_VALUE });
            dt.Rows.Add(new object[] { "March", 160, 200, MARKER_SIZE, NORMAL_VALUE });
            dt.Rows.Add(new object[] { "April", 120, 123, MARKER_SIZE, NORMAL_VALUE });
            dt.Rows.Add(new object[] { "May", 142, 150, MARKER_SIZE, NORMAL_VALUE });
            dt.Rows.Add(new object[] { "June", 180, 180, MARKER_SIZE, NORMAL_VALUE });
            dt.Rows.Add(new object[] { "July", 198, 123, MARKER_SIZE, NORMAL_VALUE });
            dt.Rows.Add(new object[] { "August", 220, 125, MARKER_SIZE, NORMAL_VALUE });
            dt.Rows.Add(new object[] { "September", 245, 124, MARKER_SIZE, NORMAL_VALUE });
            dt.Rows.Add(new object[] { "October", 208, 182, MARKER_SIZE, NORMAL_VALUE });
            dt.Rows.Add(new object[] { "November", 180, 142, MARKER_SIZE, NORMAL_VALUE });
            dt.Rows.Add(new object[] { "December", 202, 240, MARKER_SIZE, NORMAL_VALUE });

            return dt;
        }

        private void ultraDataChart1_SeriesMouseEnter(object sender, ChartMouseEventArgs e)
        {
            if (e.Series.Name == "Markers")
            {
                var item = e.Item as DataRowView;

                if (item == null)
                    return;

                item.Row.SetField<int>("Fill", HIGHLIGHT_VALUE);
            }
        }

        private void ultraDataChart1_SeriesMouseLeave(object sender, ChartMouseEventArgs e)
        {
            if (e.Series.Name == "Markers")
            {
                var item = e.Item as DataRowView;

                if (item == null)
                    return;

                item.Row.SetField<int>("Fill", NORMAL_VALUE);
            }
        }
    }
}
